Struct decaf377::AffineElement
source · pub struct AffineElement { /* private fields */ }Trait Implementations
sourceimpl<'a, 'b> Add<&'b AffineElement> for &'a AffineElement
impl<'a, 'b> Add<&'b AffineElement> for &'a AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
+ operator.sourcefn add(self, other: &'b AffineElement) -> AffineElement
fn add(self, other: &'b AffineElement) -> AffineElement
Performs the
+ operation. Read moresourceimpl<'b> Add<&'b AffineElement> for AffineElement
impl<'b> Add<&'b AffineElement> for AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
+ operator.sourcefn add(self, other: &'b AffineElement) -> AffineElement
fn add(self, other: &'b AffineElement) -> AffineElement
Performs the
+ operation. Read moresourceimpl<'a> Add<AffineElement> for &'a AffineElement
impl<'a> Add<AffineElement> for &'a AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
+ operator.sourcefn add(self, other: AffineElement) -> AffineElement
fn add(self, other: AffineElement) -> AffineElement
Performs the
+ operation. Read moresourceimpl Add<AffineElement> for AffineElement
impl Add<AffineElement> for AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
+ operator.sourcefn add(self, other: AffineElement) -> AffineElement
fn add(self, other: AffineElement) -> AffineElement
Performs the
+ operation. Read moresourceimpl<'b> AddAssign<&'b AffineElement> for AffineElement
impl<'b> AddAssign<&'b AffineElement> for AffineElement
sourcefn add_assign(&mut self, other: &'b AffineElement)
fn add_assign(&mut self, other: &'b AffineElement)
Performs the
+= operation. Read moresourceimpl AddAssign<AffineElement> for AffineElement
impl AddAssign<AffineElement> for AffineElement
sourcefn add_assign(&mut self, other: AffineElement)
fn add_assign(&mut self, other: AffineElement)
Performs the
+= operation. Read moresourceimpl AffineCurve for AffineElement
impl AffineCurve for AffineElement
const COFACTOR: &'static [u64] = _
type ScalarField = Fp256<FrParameters>
type BaseField = Fp256<FrParameters>
type Projective = Element
sourcefn prime_subgroup_generator() -> Self
fn prime_subgroup_generator() -> Self
Returns a fixed generator of unknown exponent.
sourcefn from_random_bytes(bytes: &[u8]) -> Option<Self>
fn from_random_bytes(bytes: &[u8]) -> Option<Self>
Returns a group element if the set of bytes forms a valid group element,
otherwise returns None. This function is primarily intended for sampling
random group elements from a hash-function or RNG output.
sourcefn mul<S: Into<<Self::ScalarField as PrimeField>::BigInt>>(
&self,
other: S
) -> Self::Projective
fn mul<S: Into<<Self::ScalarField as PrimeField>::BigInt>>( &self, other: S ) -> Self::Projective
Performs scalar multiplication of this element with mixed addition.
sourcefn mul_by_cofactor_to_projective(&self) -> Self::Projective
fn mul_by_cofactor_to_projective(&self) -> Self::Projective
Multiply this element by the cofactor and output the
resulting projective element.
sourcefn mul_by_cofactor_inv(&self) -> Self
fn mul_by_cofactor_inv(&self) -> Self
Multiply this element by the inverse of the cofactor in
Self::ScalarField.sourcefn into_projective(&self) -> Self::Projective
fn into_projective(&self) -> Self::Projective
Converts self into the projective representation.
sourcefn mul_by_cofactor(&self) -> Self
fn mul_by_cofactor(&self) -> Self
Multiply this element by the cofactor.
sourceimpl CanonicalDeserialize for AffineElement
impl CanonicalDeserialize for AffineElement
sourcefn deserialize<R: Read>(reader: R) -> Result<Self, SerializationError>
fn deserialize<R: Read>(reader: R) -> Result<Self, SerializationError>
Reads
Self from reader.sourcefn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where R: Read,
Reads
Self from reader without compression.sourcefn deserialize_unchecked<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_unchecked<R>(reader: R) -> Result<Self, SerializationError>where R: Read,
Reads
self from reader without compression, and without performing
validity checks. Should be used only when the input is trusted.sourceimpl CanonicalSerialize for AffineElement
impl CanonicalSerialize for AffineElement
fn serialized_size(&self) -> usize
sourcefn serialize<W: Write>(&self, writer: W) -> Result<(), SerializationError>
fn serialize<W: Write>(&self, writer: W) -> Result<(), SerializationError>
Serializes
self into writer.
It is left up to a particular type for how it strikes the
serialization efficiency vs compression tradeoff.
For standard types (e.g. bool, lengths, etc.) typically an uncompressed
form is used, whereas for algebraic types compressed forms are used. Read moresourcefn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where W: Write,
Serializes
self into writer without compression.sourcefn serialize_unchecked<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_unchecked<W>(&self, writer: W) -> Result<(), SerializationError>where W: Write,
Serializes
self into writer without compression, and without
performing validity checks. Should be used only when there is no
danger of adversarial manipulation of the output.fn uncompressed_size(&self) -> usize
sourceimpl Clone for AffineElement
impl Clone for AffineElement
sourcefn clone(&self) -> AffineElement
fn clone(&self) -> AffineElement
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AffineElement
impl Debug for AffineElement
sourceimpl Default for AffineElement
impl Default for AffineElement
sourceimpl Display for AffineElement
impl Display for AffineElement
sourceimpl From<&AffineElement> for Element
impl From<&AffineElement> for Element
sourcefn from(point: &AffineElement) -> Self
fn from(point: &AffineElement) -> Self
Converts to this type from the input type.
sourceimpl From<&Element> for AffineElement
impl From<&Element> for AffineElement
sourceimpl From<AffineElement> for Element
impl From<AffineElement> for Element
sourcefn from(point: AffineElement) -> Self
fn from(point: AffineElement) -> Self
Converts to this type from the input type.
sourceimpl From<Element> for AffineElement
impl From<Element> for AffineElement
sourceimpl FromBytes for AffineElement
impl FromBytes for AffineElement
sourceimpl Hash for AffineElement
impl Hash for AffineElement
sourceimpl<'a, 'b> Mul<&'b AffineElement> for &'a Fr
impl<'a, 'b> Mul<&'b AffineElement> for &'a Fr
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourcefn mul(self, point: &'b AffineElement) -> AffineElement
fn mul(self, point: &'b AffineElement) -> AffineElement
Performs the
* operation. Read moresourceimpl<'b> Mul<&'b AffineElement> for Fr
impl<'b> Mul<&'b AffineElement> for Fr
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourcefn mul(self, other: &'b AffineElement) -> AffineElement
fn mul(self, other: &'b AffineElement) -> AffineElement
Performs the
* operation. Read moresourceimpl<'a, 'b> Mul<&'b Fp256<FrParameters>> for &'a AffineElement
impl<'a, 'b> Mul<&'b Fp256<FrParameters>> for &'a AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourceimpl<'b> Mul<&'b Fp256<FrParameters>> for AffineElement
impl<'b> Mul<&'b Fp256<FrParameters>> for AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourceimpl<'a> Mul<AffineElement> for &'a Fr
impl<'a> Mul<AffineElement> for &'a Fr
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourcefn mul(self, other: AffineElement) -> AffineElement
fn mul(self, other: AffineElement) -> AffineElement
Performs the
* operation. Read moresourceimpl Mul<AffineElement> for Fr
impl Mul<AffineElement> for Fr
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourcefn mul(self, other: AffineElement) -> AffineElement
fn mul(self, other: AffineElement) -> AffineElement
Performs the
* operation. Read moresourceimpl<'a> Mul<Fp256<FrParameters>> for &'a AffineElement
impl<'a> Mul<Fp256<FrParameters>> for &'a AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourceimpl Mul<Fp256<FrParameters>> for AffineElement
impl Mul<Fp256<FrParameters>> for AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
* operator.sourceimpl<'b> MulAssign<&'b Fp256<FrParameters>> for AffineElement
impl<'b> MulAssign<&'b Fp256<FrParameters>> for AffineElement
sourcefn mul_assign(&mut self, point: &'b Fr)
fn mul_assign(&mut self, point: &'b Fr)
Performs the
*= operation. Read moresourceimpl MulAssign<Fp256<FrParameters>> for AffineElement
impl MulAssign<Fp256<FrParameters>> for AffineElement
sourcefn mul_assign(&mut self, other: Fr)
fn mul_assign(&mut self, other: Fr)
Performs the
*= operation. Read moresourceimpl Neg for AffineElement
impl Neg for AffineElement
sourceimpl PartialEq<AffineElement> for AffineElement
impl PartialEq<AffineElement> for AffineElement
sourcefn eq(&self, other: &AffineElement) -> bool
fn eq(&self, other: &AffineElement) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl<'a, 'b> Sub<&'b AffineElement> for &'a AffineElement
impl<'a, 'b> Sub<&'b AffineElement> for &'a AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
- operator.sourcefn sub(self, other: &'b AffineElement) -> AffineElement
fn sub(self, other: &'b AffineElement) -> AffineElement
Performs the
- operation. Read moresourceimpl<'b> Sub<&'b AffineElement> for AffineElement
impl<'b> Sub<&'b AffineElement> for AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
- operator.sourcefn sub(self, other: &'b AffineElement) -> AffineElement
fn sub(self, other: &'b AffineElement) -> AffineElement
Performs the
- operation. Read moresourceimpl<'a> Sub<AffineElement> for &'a AffineElement
impl<'a> Sub<AffineElement> for &'a AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
- operator.sourcefn sub(self, other: AffineElement) -> AffineElement
fn sub(self, other: AffineElement) -> AffineElement
Performs the
- operation. Read moresourceimpl Sub<AffineElement> for AffineElement
impl Sub<AffineElement> for AffineElement
type Output = AffineElement
type Output = AffineElement
The resulting type after applying the
- operator.sourcefn sub(self, other: AffineElement) -> AffineElement
fn sub(self, other: AffineElement) -> AffineElement
Performs the
- operation. Read moresourceimpl<'b> SubAssign<&'b AffineElement> for AffineElement
impl<'b> SubAssign<&'b AffineElement> for AffineElement
sourcefn sub_assign(&mut self, other: &'b AffineElement)
fn sub_assign(&mut self, other: &'b AffineElement)
Performs the
-= operation. Read moresourceimpl SubAssign<AffineElement> for AffineElement
impl SubAssign<AffineElement> for AffineElement
sourcefn sub_assign(&mut self, other: AffineElement)
fn sub_assign(&mut self, other: AffineElement)
Performs the
-= operation. Read more