pub struct Element { /* private fields */ }Implementations
sourceimpl Element
impl Element
sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Convenience method to make identity checks more readable.
sourcepub fn vartime_multiscalar_mul<I, J>(scalars: I, points: J) -> Element
pub fn vartime_multiscalar_mul<I, J>(scalars: I, points: J) -> Element
Given an iterator of public scalars and an iterator of public points, compute $$ Q = [c_1] P_1 + \cdots + [c_n] P_n, $$ using variable-time operations.
It is an error to call this function with two iterators of different
lengths – it would require ExactSizeIterator, but
ExactSizeIterators are not closed under chaining, and disallowing
iterator chaining would destroy the utility of the function.
sourceimpl Element
impl Element
sourcepub fn hash_to_curve(r_1: &Fq, r_2: &Fq) -> Element
pub fn hash_to_curve(r_1: &Fq, r_2: &Fq) -> Element
Maps two field elements to a uniformly distributed decaf377 Element.
The two field elements provided as inputs should be independently chosen.
sourcepub fn encode_to_curve(r: &Fq) -> Element
pub fn encode_to_curve(r: &Fq) -> Element
Maps a field element to a decaf377 Element suitable for CDH challenges.